# <span class="badge package-variant-dataquery"></span> googlecloudmonitoring

## Objects

 * <span class="badge object-type-enum"></span> [AlignmentTypes](./object-AlignmentTypes.md)
 * <span class="badge object-type-class"></span> [CloudMonitoringQuery](./object-CloudMonitoringQuery.md)
 * <span class="badge object-type-class"></span> [Filter](./object-Filter.md)
 * <span class="badge object-type-class"></span> [LegacyCloudMonitoringAnnotationQuery](./object-LegacyCloudMonitoringAnnotationQuery.md)
 * <span class="badge object-type-enum"></span> [MetricFindQueryTypes](./object-MetricFindQueryTypes.md)
 * <span class="badge object-type-enum"></span> [MetricKind](./object-MetricKind.md)
 * <span class="badge object-type-class"></span> [MetricQuery](./object-MetricQuery.md)
 * <span class="badge object-type-enum"></span> [PreprocessorType](./object-PreprocessorType.md)
 * <span class="badge object-type-class"></span> [PromQLQuery](./object-PromQLQuery.md)
 * <span class="badge object-type-enum"></span> [QueryType](./object-QueryType.md)
 * <span class="badge object-type-class"></span> [SLOQuery](./object-SLOQuery.md)
 * <span class="badge object-type-class"></span> [TimeSeriesList](./object-TimeSeriesList.md)
 * <span class="badge object-type-class"></span> [TimeSeriesQuery](./object-TimeSeriesQuery.md)
 * <span class="badge object-type-enum"></span> [ValueTypes](./object-ValueTypes.md)
## Builders

 * <span class="badge builder"></span> [CloudMonitoringQuery](./builder-CloudMonitoringQuery.md)
 * <span class="badge builder"></span> [Filter](./builder-Filter.md)
 * <span class="badge builder"></span> [LegacyCloudMonitoringAnnotationQuery](./builder-LegacyCloudMonitoringAnnotationQuery.md)
 * <span class="badge builder"></span> [MetricQuery](./builder-MetricQuery.md)
 * <span class="badge builder"></span> [PromQLQuery](./builder-PromQLQuery.md)
 * <span class="badge builder"></span> [SLOQuery](./builder-SLOQuery.md)
 * <span class="badge builder"></span> [TimeSeriesList](./builder-TimeSeriesList.md)
 * <span class="badge builder"></span> [TimeSeriesQuery](./builder-TimeSeriesQuery.md)
## Functions

### <span class="badge function"></span> variant_config

variant_config returns the configuration related to cloud-monitoring data queries.

This configuration describes how to unmarshal it, convert it to code, …

```python
def variant_config() -> variants.DataqueryConfig
```

